#!/usr/bin/python
# -*- coding: UTF-8 -*-

import os

def get_os_from_file():
    # redhat , sle : /etc/redhat-release
    # centos  :
    files=["/etc/redhat-release","/etc/centos-release","/etc/issue","/etc/os-release","/etc/SuSE-release","/etc/release"]
    res_str= ""
    ubuntu_flag = 0
    afile = ""
    for afile in files:
        exist = os.path.exists(afile)
        if exist:
            f=open(afile,'r')
            while True:
                line=f.readline()
                if not line:
                    f.close()
                    break
                if afile == "/etc/redhat-release":
                    if line.find("release") != -1:
                        f.close()
                        return text_processing(line)

                if afile == "/etc/centos-release":
                    if line.find("release") != -1:
                        f.close()
                        return text_processing(line)

                if afile == "/etc/issue":
                    if line.find("Mint") != -1:
                        f.close()
                        return text_processing(line)

                if afile == "/etc/os-release":
                    if line.find("NAME") != -1 and line.find("Ubuntu") !=-1:
                        res_str = res_str + "Ubuntu "
                        ubuntu_flag = 1
                    if line.find("VERSION") != -1 and ubuntu_flag == 1:
                        tmp = line.split("\"")
                        res_str = res_str + tmp[1]
                        f.close()
                        return text_processing(res_str)
                    if line.find("NAME") != -1 and ( line.find("SLE") != -1 or line.find("SUSE") != -1):
                        ubuntu_flag =0
                    if line.find("PRETTY_NAME") != -1 and ubuntu_flag == 0:
                        f.close()
                        tmp = line.split("\"")
                        return text_processing(tmp[1])

                if afile == "/etc/SuSE-release":
                    if line.find("openSUSE") != -1 or line.find("SLE")!=-1:
                        f.close()
                        return text_processing(line)

                if afile == "/etc/release":
                    if line.find('Solar'):
                        f.close()
                        return text_processing(line)

    print("The operating system can not resolved")
    exit(1)


def text_processing(input_text):
    if input_text == None or isinstance(input_text,str) == False or input_text == "":
        print("wrong input for text processing in op parser")
        exit(1)
    line = input_text
    if line.find('\n') != -1:
         line = line.replace('\n','')
    if line.find('\\n') != -1:
        line = line.replace('\\n','')
    if line.find('\\l') != -1:
        line = line.replace('\\l','')
    line = line.lstrip()
    line = line.rstrip()
    return line



if __name__=="__main__":
    print(get_os_from_file())



#!/usr/bin/python
# -*- coding: UTF-8 -*-

import subprocess
import codecs
import sys
import os
from platform import python_version
from svmon_client import remoteConfig

_services={}

_services['b2safe']=['b2safe','irods']
_services['gitlab']=['gitlab']
_services['svmon']=['spring','angular']
_services['b2access']=['b2access_unity']
_services['b2find']=['b2find','ckan']
_services['b2drop']=['nextcloud']
_services['dpmt']=['plone']
_services['eudat_website']=['drupal']
_services['b2gether']=['b2gether']
_services['gocdb']=['creg']
_services['b2access']=['unity']
_services['svmon_client']=['client']
_services['b2share']=["b2share"]
_services['b2handle'] = ['handle']
_services['B2HANDLE'] = ['handle']

_rpm_packages={}
_rpm_packages['b2safe']='b2safe'
_rpm_packages['irods']='irods-icat'

_tags={}
_tags['svmon']=['3.1','1.7']

def in_service_list(service_type):
    if service_type == None or service_type == "" or isinstance(service_type,str) == False:
        print("The service type argument should be a non-empty string")
        exit(1)
    if service_type in _services.keys():
        return True
    else:
        print("Your service type is unsupported. Please type --list-service-type see supported services.")
        exit(1)

def get_service_name(service_type):
    if service_type == None or service_type == "" or isinstance(service_type,str) == False:
        print("The service type argument should be a non-empty string")
        exit(1)
    if in_service_list(service_type):
        return _services.get(service_type)
    return []


def get_service_tag(service_type,configs=None):
    config = remoteConfig.RemoteConfig().getConfig()
    enableDebug = config["DEBUG_MODE"]

    if(enableDebug):
        print("Get service tag called... with service type: ", service_type)

    tags=[]
    if service_type == None or service_type == "" or isinstance(service_type,str) == False:
        print("The service type argument should be a non-empty string")
        exit(1)

    if in_service_list(service_type) == False:
        print("The service type is currently unsupported in svmon client")
        exit(1)

    if service_type == "svmon_client":
        print("Getting tag for svmon_client")
        tags.append(get_version())
        return tags

    elif service_type == "gitlab":
        tmp = get_package_version("gitlab", 0 , 1)
        if(enableDebug):
            print('get_service_tag for gitlab result: ', tmp)
        tmp = to_bytes(tmp)
        if tmp == None or tmp == '' or tmp.find('Failed'.encode('utf-8')) >-1:
            print("no gitlab version can be resolved")
            exit(1)
        tags.append(tmp)
        return tags

    elif service_type == "b2safe":
        tmp=get_package_version("b2safe")
        if(enableDebug):
            print('get_service_tag for b2safe result: ', tmp)
        if tmp == "":
            print("no b2safe version can be resolved")
            exit(1)
        tags.append(tmp)

        tmp=get_package_version("irods-server")
        if(enableDebug):
            print('get_service_tag for irods-server result: '+ tmp)
        if tmp != None and tmp != '' and tmp.find('Failed'.encode('utf-8')) == -1:
            tags.append(tmp)
            return tags
        tmp=get_package_version("irods-icat")
        if(enableDebug):
            print('get_service_tag for irods-icat result: '+tmp)
        tmp = to_bytes(tmp)
        if tmp != None and tmp != '' and tmp.find('Failed'.encode('utf-8')) == -1:
            tags.append(tmp)
            return tags
        print("No irods version can be resolved")
        exit(-1)

    elif service_type == "svmon":
        if configs != None and 'svmon_app_path' in configs:
            print('Getting svmon version from config file')
            tags={}
            if configs.get('svmon_app_path') != None and configs.get('svmon_app_path') != '' :
                svmonVersions = get_svmon_version(configs.get('svmon_app_path'))
                tags['svmon'] = [svmonVersions[1], svmonVersions[3]]
                _services['svmon']=[svmonVersions[0], svmonVersions[2]]
            return tags['svmon']
        else:
            print('No svmon configuration to get versions, returning default versions for svmon')
            return _tags['svmon']

    elif service_type == "b2handle" or service_type == "B2HANDLE":
        if configs != None and 'handle_server_path' in configs:
            tags=[]
            if configs.get('handle_server_path') != None and configs.get('handle_server_path') != '' :
                tags.append(get_handle_server(configs.get('handle_server_path')))
            return tags
        else:
            print("No b2handle configuration to get versions")
            exit(1)

def get_package_version(software,start=0,end=0):
    config = remoteConfig.RemoteConfig().getConfig()
    enableDebug = config["DEBUG_MODE"]
    print('Get_package_version for software: '+software)
    if(enableDebug):
        print('Get_package_version for software: '+software)

    if isinstance(software,str)  == False or software == "" or software == None:
        print("Software name should be a non-empty string")
        exit(1)
    if isinstance(start,int) == False or isinstance(end, int) == False:
        print("The input of indices should be integers to fetch correct version,")
        exit(1)


    osSupportsDPKG = False
    try:
        dpkgRunResult = subprocess.check_output("dpkg -l", shell=True, stderr=subprocess.STDOUT)
        osSupportsDPKG = True
    except subprocess.CalledProcessError as e:
        if(enableDebug):
            print("Tried to run dpkg, is not working on this OS, output: ", e.output)

    if osSupportsDPKG == False:
        if(enableDebug):
                print('No dpkg found, running with rpm...')
        return get_by_rpm_packages(software, start,end)

    if(enableDebug):
        print('Dpkg found, running with dpkg...')
    return get_by_dpkg_packages(software,start,end)

# for package version that can be accessed via rpm management
def get_by_dpkg_packages(software,start=0,end=0):
    config = remoteConfig.RemoteConfig().getConfig()
    enableDebug = config["DEBUG_MODE"]
    if(enableDebug):
        print('Get_by_dpkg_packages for software: '+software, start,end)

    softwareListResult = subprocess.Popen("dpkg -l", shell=True, stdout=subprocess.PIPE)
    softwareListResult = subprocess.Popen('grep ' + software, shell=True, stdin=softwareListResult.stdout, stdout=subprocess.PIPE)
    softwareListResult = softwareListResult.communicate()
    if(enableDebug):
        print('Get_by_dpkg_packages final dpkg -l before parse result: ', softwareListResult)

    if softwareListResult[0] == None or softwareListResult == "":
        print('Failed, no dpkg packages can be found for ', software)
        return ''
    softwareListResult = softwareListResult[0]

    return extractVersionFromCommandResult(software.encode('utf-8'), softwareListResult, start,end)

# for package version that can be accessed via rpm management
def get_by_rpm_packages(software,start=0,end=0):
    config = remoteConfig.RemoteConfig().getConfig()
    enableDebug = config["DEBUG_MODE"]
    if(enableDebug):
        print('Get_by_rpm_packages for software: '+software, start,end)

    softwareListResult = subprocess.Popen("rpm -qa", shell=True, stdout=subprocess.PIPE)
    softwareListResult = subprocess.Popen('grep ' + software, shell=True, stdin=softwareListResult.stdout, stdout=subprocess.PIPE)
    softwareListResult = softwareListResult.communicate()
    if(enableDebug):
        print('Get_by_rpm_packages final rpm-qa before parse result: ', softwareListResult)

    if softwareListResult[0] == None or softwareListResult == "":
        print('Failed, no rpm packages can be found for ', software)
        return ''

    return extractVersionFromCommandResult(software, softwareListResult[0], start,end)

def to_bytes(s):
    if type(s) is bytes:
        return s
    elif type(s) is str or (sys.version_info[0] < 3 and type(s) is unicode):
        return codecs.encode(s, 'utf-8')
    else:
        raise TypeError("Expected bytes or string, but got %s." % type(s))

def extractVersionFromCommandResult(software,unparsedVersion, start,end):
    software=to_bytes(software)
    unparsedVersion=to_bytes(unparsedVersion)
    softwareIndex=unparsedVersion.find(software)
    softwareIndex=softwareIndex+len(software)
    versionIndex=unparsedVersion[softwareIndex+1:len(unparsedVersion)]
    versionIndex=to_bytes(versionIndex)
    parsedVersion=versionIndex.split('-'.encode('utf-8'))

    if len(parsedVersion) > end:
        if start == end:
            return ltmp[start]
        elif start < end:
            res=""
            for i in range(start,end+1):
                res=res+ltmp[i]
            return res
        else:
            print('Failed, the start index should be smaller than end index for a correct rpm package resolver')
            return ''
    else:
        print("Failed," + software +" version not resolved")
        return ''

def get_user():
    tmp=subprocess.Popen("whoami",shell=True,stdout=subprocess.PIPE)
    tmp=tmp.communicate()
    return tmp[0].replace('\n','')

def get():
    tags=get_service_tag("svmon_client")
    return tags[0]

def get_handle_server(handle_server_path):
    tmp = subprocess.Popen(handle_server_path, shell=True, stdout = subprocess.PIPE)
    tmp = tmp.communicate()
    if tmp == None and len(tmp) < 2:
        print("Handle server executable is incorrect")
        exit(1)
    tmp = tmp[0].decode("utf-8").split('\n')
    if tmp == None or len(tmp) < 2:
        print("Handle server executable is incorrect")
        exit(1)
    tmp = tmp[0]
    tmp = tmp.split('version')
    return tmp[1].lstrip()

# get svmon backend and frontend versions
def get_svmon_version(svmon_app_path):
    config = remoteConfig.RemoteConfig().getConfig()
    cwd = os.path.dirname(svmon_app_path + '/scripts/')
    filename = cwd + "/getVersions.bash"

    if os.path.exists(filename) == False:
        print("Svmon path does not exists or missing getVersions.bash")
        exit(-1)

    if os.access(filename,os.R_OK) == False:
        print("You have no access to read script file: getVersions.bash")
        exit(-1)

    svmonVersionExecResult = subprocess.Popen(filename, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
    svmonVersionExecResult = svmonVersionExecResult.communicate()

    if svmonVersionExecResult == None and len(svmonVersionExecResult) < 1:
        print("Svmon path executable is incorrect")
        exit(1)

    # [,svmon-frontend, frontendVersion, svmon-backend, backendVersion,]
    svmonVersionsArray = svmonVersionExecResult[0].decode('utf-8').split(',')
    enableDebug = config["DEBUG_MODE"]
    if(enableDebug):
        print('SvmonVersionsArray: ')
        print(svmonVersionsArray)
        print('Length: ', len(svmonVersionsArray))

    if len(svmonVersionsArray) < 5:
        print("No versions were found for svmon")
        exit(1)

    frontendName = svmonVersionsArray[1].lstrip()
    frontendVersion = svmonVersionsArray[2].lstrip()
    backendName = svmonVersionsArray[3].lstrip()
    backendVersion = svmonVersionsArray[4].lstrip()

    return [frontendName, frontendVersion, backendName, backendVersion]

#get svmon client version
def get_version():
    config = remoteConfig.RemoteConfig().getConfig()
    enableDebug = config["DEBUG_MODE"]
    if(python_version() >= '3.0'):
        if(enableDebug):
            print("Running getVersion() for python3...")
        tmp = subprocess.Popen('python3 -m pip show svmon-client', shell=True, stdout=subprocess.PIPE)
    else:
        if(enableDebug):
            print("Running getVersion() for python2...")
        tmp = subprocess.Popen('python -m pip show svmon-client', shell=True, stdout=subprocess.PIPE)

    tmp = subprocess.Popen('grep Version', shell=True, stdin=tmp.stdout, stdout=subprocess.PIPE)
    tmp = tmp.communicate()
    tmp = tmp[0]
    if tmp == '' or tmp == None:
        print("No svmon client has been installed, please refer to https://gitlab.eudat.eu/EUDAT-TOOLS/SVMON/pysvmon")
        exit(1)
    ltmp = tmp.decode("utf-8").split('\n')
    ltmp = ltmp[0].split(':')
    if ltmp == None or len(ltmp) < 2:
        print("SVMON client can not be resolved, please check for installation")
        exit(1)
    ltmp = ltmp[1]
    ltmp.replace("\n", "")
    return ltmp

if __name__ == "__main__":
    print(get())






import sys
import os
import json
from platform import python_version

try:
    from dotenv import load_dotenv
except ImportError:
    if(python_version() >= '3.0'):
        sys.exit("You need dotenv! install it from http://pypi.python.org/pypi/python-dotenv or run python3 -m pip install python-dotenv.")
    else:
        sys.exit("You need dotenv! install it from http://pypi.python.org/pypi/python-dotenv or run python -m pip install python-dotenv.")

try:
    import requests as request
except ImportError:
    if(python_version() >= '3.0'):
        sys.exit("You need dotenv! install it from http://pypi.python.org/pypi/requests or run python3 -m pip install requests.")
    else:
        sys.exit("You need requests install it from http://pypi.python.org/pypi/requests or run python -m pip install requests")

class RemoteConfig:

    config = {}
    config['BACKEND_URL'] = 'https://svmon.eudat.eu/api/serviceComponent/jsonreport'
    config['REMOTE_CONFIG_URL'] = 'https://svmon.eudat.eu/api/remoteConfig/'
    config['DEBUG_MODE'] = False

    def __init__(self):
        load_dotenv()
        self.loadEnvVars()

    def loadRemoteConfig(self):
        try:
            headers = {}
            headers['Content-Type'] = 'application/json'
            url = self.config['REMOTE_CONFIG_URL']
            apiToken = self.getUserApiToken()

            if(apiToken):
                headers['Authorization'] = 'Bearer ' + apiToken
                url = url + 'user'
            response = request.get(url, headers=headers)
            responseBody = response.json()

            if(response.status_code != 200):
                if(self.config['DEBUG_MODE']):
                    print('Recover of remote config FAILED ', response.status_code)
                    print('Failed to load remote config, using default env vars...')
                return False
            else:
                if(self.config['DEBUG_MODE']):
                    print('Recover of remote config finished with code ', response.status_code)

            if('environments' in responseBody):
                environments = responseBody["environments"]
                if('backendUrl' in environments):
                    self.config["BACKEND_URL"] = environments["backendUrl"]
                if('debugMode' in environments):
                    self.config["DEBUG_MODE"] = environments["debugMode"]
            return True

        except request.exceptions.RequestException as e:
            if(self.config['DEBUG_MODE']):
                print('Failed to load remote config, using default env vars...')
                print(e)
            return False

    def getUserApiToken(self):
        from . import services
        cwd = os.path.dirname(services.__file__)
        apiToken = None
        filename = os.environ.get('TOKEN_PATH', cwd + "/token.json")
        if os.path.exists(filename) == False:
            return None
        if os.access(filename, os.R_OK) == False:
            return None
        with open(filename, 'r') as f:
            load_dict = json.load(f)
            if 'token' in load_dict and load_dict.get('token') != '':
                apiToken = load_dict.get('token')
            else:
                return None
        self.config['TOKEN'] = apiToken
        return apiToken

    def loadEnvVars(self):
        remoteEnvVars = self.loadRemoteConfig()
        if(remoteEnvVars and self.config['DEBUG_MODE']):
            print("Remote environment variables loaded: ")
            print(self.config)
        else:
            backendUrl = os.environ.get('BACKEND_URL', self.config['BACKEND_URL'])
            self.config['BACKEND_URL'] = backendUrl
            debugMode = os.environ.get('DEBUG_MODE', self.config['DEBUG_MODE'])
            self.config['DEBUG_MODE'] = debugMode
        return self.config

    def getConfig(self):
        return self.config



#!/usr/bin/python
# -*- coding: UTF-8 -*-

import os
import json
import subprocess
import sys
import logging
from . import services
from . import json_operations
from svmon_client import remoteConfig
from platform import python_version

try:
    from dotenv import load_dotenv
except ImportError:
    if(python_version() >= '3.0'):
        sys.exit("You need dotenv! install it from http://pypi.python.org/pypi/python-dotenv or run python3 -m pip install python-dotenv.")
    else:
        sys.exit("You need dotenv! install it from http://pypi.python.org/pypi/python-dotenv or run python -m pip install python-dotenv.")

class SVMONReport:

    def __init__(self):
        load_dotenv()
        self.site=""
        self.host=""
        self.service_names=[]
        self.service_type=""
        self.operating_system=""
        self.tags=[]
        self.config = remoteConfig.RemoteConfig().getConfig()
        cwd = os.path.dirname(services.__file__)
        filename = cwd + "/config.json"
        if os.path.exists(filename) == False:
            f=open(filename,'w')
            f.write('{"site": "kit", "service_type":"b2safe", "host":"irods-3-eudat.lsdf.kit.edu"}')
            f.close()
        readok = os.access(filename,os.R_OK)
        if readok == False:
            print("You have no access to read config file: config.json")
            exit(-1)
        with open(filename, 'r') as f:
            load_dict= json.load(f)
            self.site=str(load_dict['site'])
            self.host=str(load_dict['host'])
            self.service_type=str(load_dict['service_type'])


    def refresh_service_name_and_tag(self):
        if services.in_service_list(self.service_type) == False:
            print("service type not configured")

        if self.service_type == "b2access" or self.service_type == "b2drop" or self.service_type == "b2share":
            cwd = os.path.dirname(services.__file__)
            filename = cwd + "/components.json"
            readok = os.access(filename,os.R_OK)
            if readok == False:
                print("You have no access to read config file: components.json")
                exit(-1)
            with open(filename, 'r') as f:
                try:
                    load_dict = json.load(f)
                    if 'components' in load_dict and 'versions' in load_dict:
                        self.set_service_names(load_dict['components'])
                        self.set_tags(load_dict['versions'])

                    if len(self.service_names) != len(self.tags):
                        print("The length of the components is not equal to the versions")
                        exit(-1)

                except ValueError:
                        print("Your components.json file is not valid, please setup your configuration again or contact us for support via svmon --help")
                        exit(-1)

        else:
            if self.service_type == 'b2handle' or self.service_type == "B2HANDLE":
                b2handle_config= {}
                cwd = os.path.dirname(services.__file__)
                filename = cwd + "/config.json"
                readok = os.access(filename, os.R_OK)
                if readok == False:
                    print("You have no access to config file: config.json")
                    exit(-1)
                with open(filename, 'r') as f:
                    load_dict= json.load(f)
                    if 'handle_server_path' in load_dict:
                        if load_dict.get('handle_server_path') != None and load_dict.get('handle_server_path') != '':
                            b2handle_config['handle_server_path'] = load_dict.get('handle_server_path')
                        self.tags = services.get_service_tag(self.service_type,b2handle_config)
                        self.service_names = services.get_service_name(self.service_type)
                        return
                    else:
                        print("No configuration for b2handle, please see svmon help")
                        exit(1)

            if self.service_type == 'svmon' or self.service_type == "SVMON":
                svmon_config= {}
                cwd = os.path.dirname(services.__file__)
                filename = cwd + "/config.json"
                readok = os.access(filename, os.R_OK)
                if readok == False:
                    print("You have no access to config file: config.json")
                    exit(-1)
                with open(filename, 'r') as f:
                    load_dict= json.load(f)
                    if 'svmon_app_path' in load_dict:
                        if load_dict.get('svmon_app_path') != None and load_dict.get('svmon_app_path') != '':
                            svmon_config['svmon_app_path'] = load_dict.get('svmon_app_path')
                        self.tags = services.get_service_tag(self.service_type,svmon_config)
                        self.service_names = services.get_service_name(self.service_type)
                        return
                    else:
                        print("No configuration for svmon, please see svmon help")
                        exit(1)
            else:
                self.tags = services.get_service_tag(self.service_type)
                self.service_names = services.get_service_name(self.service_type)

    def get_site(self):
        return self.site

    def get_host(self):
        return self.host

    def get_service_names(self):
        return self.service_names

    def get_service_type(self):
        return self.service_type

    def get_tags(self):
        return self.tags

    def set_site(self,site):
        if isinstance(site,str):
            self.site=site

    def set_host(self,host):
        if isinstance(host,str):
            self.host=host

    def set_service_names(self,service_names):
        if isinstance(service_names,list):
            self.service_names=service_names

    def set_service_type(self,service_type):
        if isinstance(service_type,str):
            self.service_type=service_type

    def set_tags(self,tags):
        if isinstance(tags,list):
            self.tags=tags

    def set_operating_system(self,operating_system):
        if isinstance(operating_system,str):
            self.operating_system=operating_system

    def set_service_names_and_tags(self,service_name,tag):
        this.service_names.append(service_name)
        this.tags.append(tag)

    def print_report(self):
        enableDebug = self.config["DEBUG_MODE"]
        if(enableDebug):
            print('print_report called with services: ', self.service_names)
        if len(self.service_names) > 0:
            res=[]
            if self.service_names== None or len(self.service_names ) < 1:
                print("no service names is resolved at your host")
                exit(1)
            if  self.tags == None or len(self.tags) < 1:
                print("no service component version is resolved at your host")
                exit(1)

            serviceVersionIterator=0
            for serviceIterator in range(len(self.service_names)):
                if serviceVersionIterator < len(self.tags) and self.tags[serviceVersionIterator] != None and self.tags[serviceVersionIterator] != "" :
                    tagsDecoded = self.tags[serviceVersionIterator]
                    res.append(self.site+'\t'+self.host+'\t'+self.operating_system+'\t'+self.service_type+'\t'+self.service_names[serviceIterator]+'\t'+tagsDecoded+'\n')
                    serviceVersionIterator = serviceVersionIterator +1
            return res
        else:
            print("Zero service components")
            return []

    def jsonify(self):
        if len(self.service_names) > 0:
            res = {}
            res['site']= self.site
            res['host'] = self.host
            res['operating_system'] = self.operating_system
            res['service_type'] = self.service_type
            res['service_names'] = self.service_names
            res['tags'] = self.tags
            return res
        else:
            print("No services to be jsonified")
            return {}

    def save_b2handle_config_to_json(self,handle_server_path=None):
        if handle_server_path == None :
            print("No b2handle configuration input")
            exit(-1)
        if handle_server_path != None and isinstance(handle_server_path,str) == False:
            print("Handle server path should be a string")
            exit(-1)
        if  handle_server_path == "":
            print("No input for b2handle configuration")
            exit(-1)

        res={}
        res['site']= self.site
        res['host'] = self.host
        res['service_type'] = self.service_type
        if handle_server_path != "":
            res['handle_server_path'] = handle_server_path

        cwd = os.path.dirname(services.__file__)
        filename = cwd + "/config.json"
        writeok = os.access(filename, os.W_OK)
        if writeok == False:
            print("You have no access to write config file: config.json")
            exit(-1)
        success = json_operations.save_to_file(filename,res)
        if success == False:
            print("Save json data failed")
            exit(1)
        else:
            print("Saved B2HANDLE configuration")

    def save_svmon_app_path(self,svmon_app_path=None):
        if svmon_app_path == None :
            print("No svmon_app_path configuration input")
            exit(-1)
        if svmon_app_path != None and isinstance(svmon_app_path,str) == False:
            print("Svmon path should be a string")
            exit(-1)
        if  svmon_app_path == "":
            print("No input for svmon_app_path")
            exit(-1)

        res={}
        res['site']= self.site
        res['host'] = self.host
        res['service_type'] = self.service_type
        res['svmon_app_path'] = svmon_app_path

        cwd = os.path.dirname(services.__file__)
        filename = cwd + "/config.json"
        writeok = os.access(filename, os.W_OK)
        if writeok == False:
            print("You have no access to write config file: config.json")
            exit(-1)
        success = json_operations.save_to_file(filename,res)
        if success == False:
            print("Save json data failed")
            exit(1)
        else:
            print("Saved SVMON configuration")

    def save_to_json(self):
        if self.site != "" and self.site != None:
            res = {}
            res['site']= self.site
            res['host'] = self.host
            res['service_type'] = self.service_type
            if self.service_type == "b2handle" or self.service_type == "B2HANDLE":
                cwd = os.path.dirname(services.__file__)
                filename = cwd + "/config.json"
                with open(filename, 'r') as f:
                    load_dict= json.load(f)
                    if 'handle_server_path' in load_dict and load_dict.get('handle_server_path') != None and load_dict.get('handle_server_path') != "":
                        res['handle_server_path'] = load_dict.get('handle_server_path')

            cwd = os.path.dirname(services.__file__)
            filename = cwd + "/config.json"
            if os.path.exists(filename) == False:
                f = open(filename, 'w')
                f.close()
            writeok = os.access(filename, os.W_OK)
            if writeok == False:
                print("You have no access to write config file: config.json")
                exit(-1)
            success = json_operations.save_to_file(filename,res)
            if success == False:
                print("Save json data failed")
                exit(1)
        else:
            print("No services to be jsonified")
            exit(1)

    def save_with_components_to_json(self,specified_components, specified_versions):

        if specified_components== None or specified_versions == None and len(specified_versions) == 0 \
                and len(specified_components) ==0 and len(specified_versions) != len(specified_components):
            print("Please input valid service components and versions to save")
            exit(1)


        cwd = os.path.dirname(services.__file__)
        filename = cwd + "/components.json"
        if os.path.exists(filename) == False:
            f=open(filename,'w')
            f.close()

        writeok = os.access(filename,os.W_OK)
        if writeok == False:
            print("You have no access to write config file: components.json")
            exit(-1)

        res = {}
        res['components'] = specified_components
        res['versions'] = specified_versions

        success = json_operations.save_to_file(filename,res)
        if success == False:
            print("Save component data failed")
            exit(1)
        else:
            print("Successfully saved component data")
            exit(1)

    def set_pair(self,key,value):
        if isinstance(key,str) == False:
            print("Key should be a string")
            exit(1)

        if key == "site":
            self.set_site(value)
        elif key == "host":
            self.set_host(value)
        elif key == "service_type":
            self.set_service_type(value)
        elif key == "operating_system":
            self.set_operating_system(value)
        elif key == "service_names":
            self.set_service_names(value)
        elif key == "tags":
            self.set_tags(value)
        else :
            print("such key is not supported: %s\n" %key)
            exit(1)

    def check_site(self):
        return True

    def check_host(self):
        return True

    def print_config_file(self):
        cwd = os.path.dirname(services.__file__)
        filename = cwd + "/config.json"
        with open(filename, 'r') as f:
            load_dict = json.load(f)
            print("The following are your current configurations: ")
            for k, v in load_dict.items():
                print(str(k) +'=  ' +str(v))
            print('Please use svmon --site <SITE> --host <HOST> --type <TYPE> --dump to change your configuration')
            print('More details, please see svmon --help')

    def send_report_to_svmon_server(self):
       import requests as re
       print('Sending report to svmon server...')
       cwd = os.path.dirname(services.__file__)
       apiToken = ""
       filename = os.environ.get('TOKEN_PATH', cwd + "/token.json")
       if os.path.exists(filename) == False:
           print("You have no token configured, please go to svmon.eudat.eu webpage  to create a token and configure it")
           exit(-1)
       readok = os.access(filename, os.R_OK)
       if readok == False:
           print("You have no access to read config file: token.json")
           exit(-1)
       with open(filename, 'r') as f:
           load_dict = json.load(f)
           if 'token' in load_dict and load_dict.get('token') != '':
               apiToken = load_dict.get('token')
           else:
               print("Please configure api token")
               exit(1)

       url = self.config['BACKEND_URL']
       enableDebug = self.config['DEBUG_MODE']
       if(enableDebug):
           print("BACKEND_URL :" + url)

       headers = {}
       headers['Content-Type'] = 'application/json'
       headers['Authorization'] = 'Bearer ' + apiToken

       cert = os.environ.get('CERTIFICATE_PATH', cwd + "/chain_TERENA_SSL_CA_3.pem")
       if(not len(self.service_names)):
           print('No services available, sending report failed')
           exit(1)

       postErrors = 0
       for i in range(len(self.service_names)):
           res = {}
           res['siteName']=self.site
           res['hostNameId']=self.host
           res['operatingSystem']=self.operating_system
           res['serviceType']=self.service_type
           res['serviceComponentName']=self.service_names[i]
           res['tagAtSite']=self.tags[i]
           if(enableDebug):
               print('Going to send report: ',res,' to endpoint: ' + url)
               print('Certificate path: ', cert)
           try:
               if(enableDebug):
                   logging.basicConfig()
                   logging.getLogger().setLevel(logging.DEBUG)
                   requests_log = logging.getLogger("requests.packages.urllib3")
                   requests_log.setLevel(logging.DEBUG)
                   requests_log.propagate = True

               r = re.post(url, data=json.dumps(res), headers=headers, verify=cert)
               #r = re.post(url, headers=headers, data=json.dumps(res), verify=False)
               print('Request to svmon server finished with status code:', r.status_code)
               if(r.status_code == 401):
                   print('Sending report failed, user not authorized, did you provided a valid token?, please check your token.json')
                   exit(1)
               if(r.status_code == 404):
                   print('Service ', self.service_type,' does not exists, please check the svmon config')
                   postErrors +=1
                   continue
               if(r.status_code == 400):
                   print(r.json())
                   postErrors +=1
                   continue
               if (r.status_code != 201 and r.status_code != 200):
                   print('Sending report failed, please check your configuration')
                   exit(1)
           except re.exceptions.RequestException as e:
               print('Sending report failed, host offline?')
               exit(1)
       if(postErrors > 0):
           if(postErrors == len(self.service_names)):
               print('Sending report failed, please check your configuration')
               exit(1)
           print('Sending report finished with some failed reports: ${postErrors}/${len(self.service_names)}, please check your configuration')
           exit(1)
       print('Report has been sent successfully.')
       exit(0)

    def save_token(self,token):
        print('Saving token...')
        if token == "":
            print("No token to be saved")
            exit(0)
        cwd = os.path.dirname(services.__file__)
        filename = cwd + "/token.json"
        res={}
        res['token'] = token
        if os.path.exists(filename) == False:
            f = open(filename, 'w')
            f.close()
        writeok = os.access(filename, os.W_OK)
        if writeok == False:
            print("You have no access to write config file: token.json")
            exit(-1)
        success = json_operations.save_to_file(filename, res)
        if success == False:
            print("Save token data  to json failed")
            exit(1)


if __name__=="__main__":
    re=SVMONReport()
    re.save_to_json()



#!/usr/bin/python
# -*- coding: UTF-8 -*-
from setuptools import setup

setup(
name='svmon-client',
version='2.4.3',
packages=['svmon_client'],
scripts=['svmon'],
package_data={'' : ['*.json','*.pem']},
description='This is a python implementation of SVMON client',
long_description=open('README.rst').read(),
author='Jie Yuan',
author_email='jie.yuan@kit.edu',
maintainer='Agustin Pane',
maintainer_email='agustin.pane@kit.edu',
license='MIT License',
platforms=["all"],
install_requires=[
  'python-dotenv',
  'requests',
],
url='https://gitlab.eudat.eu/EUDAT-TOOLS/SVMON/pysvmon',
classifiers=[
    'Development Status :: 4 - Beta',
    'Operating System :: OS Independent',
    'Intended Audience :: Developers',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python',
    'Programming Language :: Python :: Implementation',
    'Programming Language :: Python :: 2.7',
    'Topic :: Software Development :: Libraries' ]
)
